# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['utils']

package_data = \
{'': ['*']}

install_requires = \
['blessed>=1.20.0,<2.0.0', 'tabulate>=0.9.0,<0.10.0', 'xcsv>=0.4,<1.0']

entry_points = \
{'console_scripts': ['xcsv_print = xcsv.utils.__main__:main']}

setup_kwargs = {
    'name': 'xcsv-utils',
    'version': '0.1.1',
    'description': 'Subpackage of utilities for extended CSV (XCSV) files',
    'long_description': "# xcsv-utils\n\nxcsv-utils is a subpackage of [xcsv](https://github.com/paul-breen/xcsv).  It's main purpose is to provide utilities for working with extended CSV (XCSV) files.\n\n## Install\n\nThe package can be installed from PyPI:\n\n```bash\n$ pip install xcsv-utils\n```\n\n## Using the package\n\nXCSV data can be printed directly, as the data table is a [pandas](https://pandas.pydata.org/docs/index.html) table:\n\n```python\n>>> content.data\n     time (year) [a]  depth (m)\n0               2012      0.575\n1               2011      1.125\n2               2010      2.225\n3               2009      2.825\n4               2008      3.508\n..               ...        ...\n387             1625    132.240\n388             1624    132.426\n389             1623    132.680\n390             1622    132.880\n391             1621    133.180\n\n[392 rows x 2 columns]\n```\n\nBut an XCSV object usually contains an extended header section as well as the data.  Pandas doesn't handle this header, but the XCSV object does.  In addition, the XCSV object parses the data table column headers and makes their content machine-readable.\n\nThe `xcsv-utils` subpackage provides simple access and visual inspection of the attributes of an XCSV object - the `metadata` (`header` and `column_headers`) and the `data`.  The main class is `Print`, which provides a formatted, themed view of an XCSV object, and can pretty-print an XCSV file directly from the command line.  This is the purpose of the `xcsv-utils` subpackage.  For example:\n\n```bash\n$ python3 -m xcsv.utils example.csv \nid: 1\ntitle: The title\nsummary: This dataset...\nThe second summary paragraph.\nThe third summary paragraph.  Escaped because it contains the delimiter in a URL https://dummy.domain\nauthors: A B, C D\ninstitution: BAS (British Antarctic Survey).\nlatitude: -73.86 (degree_north)\nlongitude: -65.46 (degree_east)\nelevation: 1897 (m a.s.l.)\n[a]: 2012 not a complete year\n+----+--------------+-------------+\n|    |         time |   depth (m) |\n|    |   (year) [a] |             |\n|----+--------------+-------------|\n|  0 |         2012 |       0.575 |\n|  1 |         2011 |       1.125 |\n|  2 |         2010 |       2.225 |\n+----+--------------+-------------+\n```\n\nAll the colour theming is handled by the [blessed](https://pypi.org/project/blessed/) package, and the data table formatting is handled by the [tabulate](https://pypi.org/project/tabulate/) package.\n\nNote here that we're calling `xcsv-utils` as a *module main*.  As a convenience, this invocation is wrapped as a console script (called `xcsv_print`) when installing the package, hence the following invocation is equivalent:\n\n```bash\n$ xcsv_print example.csv\n```\n\nA key feature of the CLI, is that the attributes of the XCSV object can be inspected individually.  When called with no options, the header is printed in a themed and formatted way, followed by the data table, which is also themed and formatted.  This is more readable than simply `cat`ing the file.  The modes of the CLI are:\n\n* No options: Print the header, followed by the data table.\n* `-H`: Print the header only.\n* `-C`: Print the column headers only.  These are printed with a numeric index, so that optionally a subset of columns can be specified when printing the data table.\n* `-D`: Print the data table only.  The rows have a leading row index column (as per usual with `pandas` dataframes), so that optionally a subset of rows can be specified when printing the data table.\n\nFor example:\n\n```bash\n$ xcsv_print example.csv -H\nid: 1\ntitle: The title\nsummary: This dataset...\nThe second summary paragraph.\nThe third summary paragraph.  Escaped because it contains the delimiter in a URL https://dummy.domain\nauthors: A B, C D\ninstitution: BAS (British Antarctic Survey).\nlatitude: -73.86 (degree_north)\nlongitude: -65.46 (degree_east)\nelevation: 1897 (m a.s.l.)\n[a]: 2012 not a complete year\n```\n\n```bash\n$ xcsv_print example.csv -C\n   0 time (year) [a]\n   1 depth (m)\n```\n\n```bash\n$ xcsv_print example.csv -D\n+----+--------------+-------------+\n|    |         time |   depth (m) |\n|    |   (year) [a] |             |\n|----+--------------+-------------|\n|  0 |         2012 |       0.575 |\n|  1 |         2011 |       1.125 |\n|  2 |         2010 |       2.225 |\n+----+--------------+-------------+\n```\n\nThese modes are mutually exclusive.  Each of these options can be combined with the verbose (`-v`) option, to highlight how that attribute was parsed.  For example, when verbosely printing the header, any numeric values with units, and any list items, will be highlighted:\n\n```bash\n$ xcsv_print example.csv -Hv\nid: 1\ntitle: The title\nsummary: ['This dataset...', 'The second summary paragraph.', 'The third summary paragraph.  Escaped because it contains the delimiter in a URL https://dummy.domain']\nauthors: A B, C D\ninstitution: BAS (British Antarctic Survey).\nlatitude: value: -73.86, units: degree_north\nlongitude: value: -65.46, units: degree_east\nelevation: value: 1897, units: m a.s.l.\n[a]: 2012 not a complete year\n```\n\nSimilarly for the column headers:\n\n```bash\n$ xcsv_print example.csv -Cv\n   0 name: time, units: year, notes: a\n   1 name: depth, units: m, notes: None\n```\n\nand the data table:\n\n```bash\n$ xcsv_print example.csv -Dv\n+----+---------------+---------------+\n|    |    name: time |   name: depth |\n|    |   units: year |      units: m |\n|    |      notes: a |   notes: None |\n|----+---------------+---------------|\n|  0 |          2012 |         0.575 |\n|  1 |          2011 |         1.125 |\n|  2 |          2010 |         2.225 |\n+----+---------------+---------------+\n```\n\nThe data table also has an extra verbose (`-vv`) option whereby it will resolve any table notes to the notes text from the coresponding header item:\n\n```bash\n$ xcsv_print example.csv -Dvv\n+----+-----------------------------------+---------------+\n|    |                        name: time |   name: depth |\n|    |                       units: year |      units: m |\n|    |   notes: a -> 2012 not a complete |   notes: None |\n|    |                              year |               |\n|----+-----------------------------------+---------------|\n|  0 |                              2012 |         0.575 |\n|  1 |                              2011 |         1.125 |\n|  2 |                              2010 |         2.225 |\n+----+-----------------------------------+---------------+\n```\n\nThere are further useful options for printing the data table:\n\n* `-c`: Specify a subset of columns to print.  This can be useful when the data table contains a large number of columns.\n* `-r`: Similarly, specify a subset of rows to print.\n* `--head`: Convenience function.  Print only the first 10 data rows.\n* `--tail`: Convenience function.  Print only the last 10 data rows.\n\nAll column and row indices are zero-based, and can be ascertained from the `-C` and `-D` options respectively.  They can be specified as comma-separated lists and/or hyphen-separated (inclusive) ranges.\n\nOf course the OS `head` and `tail` (and `less`) commands can be used to limit the output of the table, but doing so will lose the theming.  Moreover though, if the output includes the header, then `head` will apply to the header, and will likely not get as far as showing any of the data table.\n\nFor example:\n\n```bash\n$ xcsv_print -D --head A68_icebergs_positions_and_dimensions_2020-21-A68A.csv\n+----+------------+--------------------+--------------------+---------------------------+---------------------------+---------------------------+---------------------------+-------------------------+--------------------------+-------------+-----------------------------------------------------------------+\n|    | Date       |   A68A_Central_Lat |   A68A_Central_Lon |   A68A_Long_axis_end_Lat1 |   A68A_Long_axis_end_Lon1 |   A68A_Long_axis_end_Lat2 |   A68A_Long_axis_end_Lon2 |   A68A_Long_axis_length |   A68A_Short_axis_length |   A68A_Area | Dimensions_source                                               |\n|    |            |     (degree_north) |      (degree_east) |            (degree_north) |             (degree_east) |            (degree_north) |             (degree_east) |                    (km) |                     (km) |       (km2) |                                                                 |\n|----+------------+--------------------+--------------------+---------------------------+---------------------------+---------------------------+---------------------------+-------------------------+--------------------------+-------------+-----------------------------------------------------------------|\n|  0 | 2020-09-01 |             -59.42 |             -49.47 |                    -59.63 |                    -50.51 |                    -59.26 |                    -47.98 |                 nan     |                  nan     |      nan    | 9999                                                            |\n|  1 | 2020-09-02 |             -59.42 |             -49.49 |                    -59.8  |                    -50.52 |                    -59.11 |                    -48.3  |                 nan     |                  nan     |      nan    | 9999                                                            |\n|  2 | 2020-09-03 |             -59.46 |             -49.7  |                    -60.04 |                    -50.18 |                    -58.88 |                    -48.9  |                 149.375 |                   49.875 |     4451.66 | s1a-ew-grd-hh-20200903t223918-20200903t224018-034200-03f92b-001 |\n|  3 | 2020-09-04 |             -59.43 |             -49.72 |                    -60.11 |                    -49.77 |                    -58.78 |                    -49.43 |                 nan     |                  nan     |      nan    | 9999                                                            |\n|  4 | 2020-09-05 |             -59.45 |             -49.72 |                    -60.06 |                    -49.49 |                    -58.73 |                    -49.72 |                 nan     |                  nan     |      nan    | 9999                                                            |\n|  5 | 2020-09-06 |             -59.44 |             -49.66 |                    -59.98 |                    -49.19 |                    -58.69 |                    -50.02 |                 nan     |                  nan     |      nan    | 9999                                                            |\n|  6 | 2020-09-07 |             -59.38 |             -49.69 |                    -59.84 |                    -49    |                    -58.69 |                    -50.27 |                 nan     |                  nan     |      nan    | 9999                                                            |\n|  7 | 2020-09-08 |             -59.31 |             -49.66 |                    -59.73 |                    -48.85 |                    -58.7  |                    -50.48 |                 nan     |                  nan     |      nan    | 9999                                                            |\n|  8 | 2020-09-09 |             -59.29 |             -49.68 |                    -59.72 |                    -48.85 |                    -58.67 |                    -50.47 |                 nan     |                  nan     |      nan    | 9999                                                            |\n|  9 | 2020-09-10 |             -59.26 |             -49.7  |                    -59.7  |                    -48.85 |                    -58.64 |                    -50.45 |                 nan     |                  nan     |      nan    | 9999                                                            |\n+----+------------+--------------------+--------------------+---------------------------+---------------------------+---------------------------+---------------------------+-------------------------+--------------------------+-------------+-----------------------------------------------------------------+\n$ xcsv_print -C A68_icebergs_positions_and_dimensions_2020-21-A68A.csv\n   0 Date\n   1 A68A_Central_Lat (degree_north)\n   2 A68A_Central_Lon (degree_east)\n   3 A68A_Long_axis_end_Lat1 (degree_north)\n   4 A68A_Long_axis_end_Lon1 (degree_east)\n   5 A68A_Long_axis_end_Lat2 (degree_north)\n   6 A68A_Long_axis_end_Lon2 (degree_east)\n   7 A68A_Long_axis_length (km)\n   8 A68A_Short_axis_length (km)\n   9 A68A_Area (km2)\n  10 Dimensions_source\n$ xcsv_print -D --head -c 0-2 A68_icebergs_positions_and_dimensions_2020-21-A68A.csv\n+----+------------+--------------------+--------------------+\n|    | Date       |   A68A_Central_Lat |   A68A_Central_Lon |\n|    |            |     (degree_north) |      (degree_east) |\n|----+------------+--------------------+--------------------|\n|  0 | 2020-09-01 |             -59.42 |             -49.47 |\n|  1 | 2020-09-02 |             -59.42 |             -49.49 |\n|  2 | 2020-09-03 |             -59.46 |             -49.7  |\n|  3 | 2020-09-04 |             -59.43 |             -49.72 |\n|  4 | 2020-09-05 |             -59.45 |             -49.72 |\n|  5 | 2020-09-06 |             -59.44 |             -49.66 |\n|  6 | 2020-09-07 |             -59.38 |             -49.69 |\n|  7 | 2020-09-08 |             -59.31 |             -49.66 |\n|  8 | 2020-09-09 |             -59.29 |             -49.68 |\n|  9 | 2020-09-10 |             -59.26 |             -49.7  |\n+----+------------+--------------------+--------------------+\n$ xcsv_print -D --head -c 0,3-6 A68_icebergs_positions_and_dimensions_2020-21-A68A.csv\n+----+------------+---------------------------+---------------------------+---------------------------+---------------------------+\n|    | Date       |   A68A_Long_axis_end_Lat1 |   A68A_Long_axis_end_Lon1 |   A68A_Long_axis_end_Lat2 |   A68A_Long_axis_end_Lon2 |\n|    |            |            (degree_north) |             (degree_east) |            (degree_north) |             (degree_east) |\n|----+------------+---------------------------+---------------------------+---------------------------+---------------------------|\n|  0 | 2020-09-01 |                    -59.63 |                    -50.51 |                    -59.26 |                    -47.98 |\n|  1 | 2020-09-02 |                    -59.8  |                    -50.52 |                    -59.11 |                    -48.3  |\n|  2 | 2020-09-03 |                    -60.04 |                    -50.18 |                    -58.88 |                    -48.9  |\n|  3 | 2020-09-04 |                    -60.11 |                    -49.77 |                    -58.78 |                    -49.43 |\n|  4 | 2020-09-05 |                    -60.06 |                    -49.49 |                    -58.73 |                    -49.72 |\n|  5 | 2020-09-06 |                    -59.98 |                    -49.19 |                    -58.69 |                    -50.02 |\n|  6 | 2020-09-07 |                    -59.84 |                    -49    |                    -58.69 |                    -50.27 |\n|  7 | 2020-09-08 |                    -59.73 |                    -48.85 |                    -58.7  |                    -50.48 |\n|  8 | 2020-09-09 |                    -59.72 |                    -48.85 |                    -58.67 |                    -50.47 |\n|  9 | 2020-09-10 |                    -59.7  |                    -48.85 |                    -58.64 |                    -50.45 |\n+----+------------+---------------------------+---------------------------+---------------------------+---------------------------+\n$ xcsv_print -D --head -c 0,7-8 A68_icebergs_positions_and_dimensions_2020-21-A68A.csv\n+----+------------+-------------------------+--------------------------+\n|    | Date       |   A68A_Long_axis_length |   A68A_Short_axis_length |\n|    |            |                    (km) |                     (km) |\n|----+------------+-------------------------+--------------------------|\n|  0 | 2020-09-01 |                 nan     |                  nan     |\n|  1 | 2020-09-02 |                 nan     |                  nan     |\n|  2 | 2020-09-03 |                 149.375 |                   49.875 |\n|  3 | 2020-09-04 |                 nan     |                  nan     |\n|  4 | 2020-09-05 |                 nan     |                  nan     |\n|  5 | 2020-09-06 |                 nan     |                  nan     |\n|  6 | 2020-09-07 |                 nan     |                  nan     |\n|  7 | 2020-09-08 |                 nan     |                  nan     |\n|  8 | 2020-09-09 |                 nan     |                  nan     |\n|  9 | 2020-09-10 |                 nan     |                  nan     |\n+----+------------+-------------------------+--------------------------+\n# Replicate the combined --head and --tail functionality with the -r option\n$ xcsv_print -D -c 0,7-8 -r 0-9,218-227 A68_icebergs_positions_and_dimensions_2020-21-A68A.csv\n+-----+------------+-------------------------+--------------------------+\n|     | Date       |   A68A_Long_axis_length |   A68A_Short_axis_length |\n|     |            |                    (km) |                     (km) |\n|-----+------------+-------------------------+--------------------------|\n|   0 | 2020-09-01 |                 nan     |                  nan     |\n|   1 | 2020-09-02 |                 nan     |                  nan     |\n|   2 | 2020-09-03 |                 149.375 |                   49.875 |\n|   3 | 2020-09-04 |                 nan     |                  nan     |\n|   4 | 2020-09-05 |                 nan     |                  nan     |\n|   5 | 2020-09-06 |                 nan     |                  nan     |\n|   6 | 2020-09-07 |                 nan     |                  nan     |\n|   7 | 2020-09-08 |                 nan     |                  nan     |\n|   8 | 2020-09-09 |                 nan     |                  nan     |\n|   9 | 2020-09-10 |                 nan     |                  nan     |\n| 218 | 2021-04-07 |                 nan     |                  nan     |\n| 219 | 2021-04-08 |                 nan     |                  nan     |\n| 220 | 2021-04-09 |                 nan     |                  nan     |\n| 221 | 2021-04-10 |                 nan     |                  nan     |\n| 222 | 2021-04-11 |                 nan     |                  nan     |\n| 223 | 2021-04-12 |                 nan     |                  nan     |\n| 224 | 2021-04-13 |                 nan     |                  nan     |\n| 225 | 2021-04-14 |                 nan     |                  nan     |\n| 226 | 2021-04-15 |                 nan     |                  nan     |\n| 227 | 2021-04-16 |                 nan     |                  nan     |\n+-----+------------+-------------------------+--------------------------+\n```\n\nIn general, the default theme works OK in a dark- or light- background terminal.  The default theme (`light`) assumes a dark background.  If highlighted text is difficult to read on a light background, then specify the `dark` theme instead (`-t dark`).\n\nIn addition to using the CLI, the package can be used as a Python library.  The main class is `Print` which provides methods to pretty-print a given dataset (XCSV object):\n\n```python\n>>> import xcsv\n>>> import xcsv.utils as xu\n>>> filename = 'example.csv'\n>>> with xcsv.File(filename) as f:\n>>>     dataset = f.read()\n>>> printer = xu.Print(metadata=dataset.metadata, data=dataset.data)\n>>> printer.print_data()\n+----+--------------+-------------+\n|    |         time |   depth (m) |\n|    |   (year) [a] |             |\n|----+--------------+-------------|\n|  0 |         2012 |       0.575 |\n|  1 |         2011 |       1.125 |\n|  2 |         2010 |       2.225 |\n+----+--------------+-------------+\n# To access the formatted and themed string, we can do the following\n>>> output = printer.format_data()\n>>> output\n'+----+----------+---------+\\n|    |     \\x1b[38;2;190;190;190m\\x1b[38;2;190;190;190m\\x1b[38;2;190;190;190mtime\\x1b[m\\x1b[m\\x1b[m |   \\x1b[38;2;190;190;190m\\x1b[38;2;190;190;190m\\x1b[38;2;190;190;190mdepth\\x1b[m\\x1b[m |\\n|    |   \\x1b[38;2;190;190;190m\\x1b[38;2;190;190;190m\\x1b[38;2;190;190;190m(year)\\x1b[m\\x1b[m |     \\x1b[38;2;190;190;190m\\x1b[38;2;190;190;190m(m)\\x1b[m\\x1b[m\\x1b[m |\\n|    |      \\x1b[38;2;190;190;190m\\x1b[38;2;190;190;190m[a]\\x1b[m\\x1b[m\\x1b[m |         |\\n|----+----------+---------|\\n|  0 |     2012 |   0.575 |\\n|  1 |     2011 |   1.125 |\\n|  2 |     2010 |   2.225 |\\n+----+----------+---------+'\n>>> print(output)\n+----+----------+---------+\n|    |     time |   depth |\n|    |   (year) |     (m) |\n|    |      [a] |         |\n|----+----------+---------|\n|  0 |     2012 |   0.575 |\n|  1 |     2011 |   1.125 |\n|  2 |     2010 |   2.225 |\n+----+----------+---------+\n>>> printer.columns = [1]\n>>> printer.print_data()\n+----+---------+\n|    |   depth |\n|    |     (m) |\n|----+---------|\n|  0 |   0.575 |\n|  1 |   1.125 |\n|  2 |   2.225 |\n+----+---------+\n>>> printer.print_header()\nid: 1\ntitle: The title\nsummary: This dataset...\nThe second summary paragraph.\nThe third summary paragraph.  Escaped because it contains the delimiter in a URL https://dummy.domain\nauthors: A B, C D\ninstitution: BAS (British Antarctic Survey).\nlatitude: -73.86 (degree_north)\nlongitude: -65.46 (degree_east)\nelevation: 1897 (m a.s.l.)\n[a]: 2012 not a complete year\n>>> printer.verbose = 1\n>>> printer.print_header()\nid: 1\ntitle: The title\nsummary: ['This dataset...', 'The second summary paragraph.', 'The third summary paragraph.  Escaped because it contains the delimiter in a URL https://dummy.domain']\nauthors: A B, C D\ninstitution: BAS (British Antarctic Survey).\nlatitude: value: -73.86, units: degree_north\nlongitude: value: -65.46, units: degree_east\nelevation: value: 1897, units: m a.s.l.\n[a]: 2012 not a complete year\n>>> printer.print_column_headers()\n   0 name: time, units: year, notes: a\n   1 name: depth, units: m, notes: None\n```\n\n## Command line usage\n\nCalling the script with the `--help` option will show the following usage:\n\n```bash\n$ python3 -m xcsv.utils --help\nusage: xcsv_print [-h] [-H] [-C] [-D] [-c COLUMNS] [-r ROWS] [--head]\n                  [--tail] [-t {light,dark}] [-v] [-V]\n                  in_file\n\nprint xcsv file\n\npositional arguments:\n  in_file               input XCSV file\n\noptional arguments:\n  -h, --help            show this help message and exit\n  -H, --header-only     show the extended header section only\n  -C, --column-headers-only\n                        show the data table column headers only\n  -D, --data-only       show the data table only\n  -c COLUMNS, --columns COLUMNS\n                        columns to include in the data table (specify\n                        multiple columns separated by commas and/or as\n                        hyphen-separated ranges)\n  -r ROWS, --rows ROWS  rows to include in the data table (specify multiple\n                        rows separated by commas and/or as hyphen-separated\n                        ranges)\n  --head                only show the first 10 rows of the data table\n  --tail                only show the last 10 rows of the data table\n  -t {light,dark}, --theme {light,dark}\n                        use the named theme to apply styling to the output\n  -v, --verbose         show incrementally verbose output\n  -V, --version         show program's version number and exit\n```\n\n",
    'author': 'Paul Breen',
    'author_email': 'pbree@bas.ac.uk',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/paul-breen/xcsv-utils',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
